import pandas as pd


class Unicov():
    ''' This class will be used to create a object and then use to read the file data and get it's type'''
    pass

    # def read_file(self, input_file, delimiter=""):
    #     ''' This function will read the file and get the data as well as file type and any other required parameters'''
    #     pass

    #     # return file_data, file_type



if __name__ == "__main__":
    # file_data, file_type = read_file()
    pass